__author__ = 'Evgeny Safronov <division494@gmail.com>'


APPS_TAGS = ('app',)
RUNLISTS_TAGS = ('runlist',)
PROFILES_TAGS = ('profile',)
GROUPS_TAGS = ('group', 'active')
